==> react-form-mobx-0.2.1.tgz: package/es/FormStore/FormStore.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class, _descriptor, _descriptor2, _descriptor3;

function _initDefineProp(target, property, descriptor, context) {
	if (!descriptor) return;
	Object.defineProperty(target, property, {
		enumerable: descriptor.enumerable,
		configurable: descriptor.configurable,
		writable: descriptor.writable,
		value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	});
}

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _initializerWarningHelper(descriptor, context) {
	throw new Error('Decorating class property failed. Please ensure that transform-class-properties is enabled.');
}

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

import { action } from 'mobx';
import { isFunction, isArray as isArrayType, createId } from '../utils';
import PrimitiveStore from './PrimitiveStore';
import ObjectStore from './ObjectStore';
import ArrayStore from './ArrayStore';

var FormStore = (_class = function (_ObjectStore) {
	_inherits(FormStore, _ObjectStore);

	function FormStore(pristineValue, options) {
		_classCallCheck(this, FormStore);

		var _this = _possibleConstructorReturn(this, (FormStore.__proto__ || Object.getPrototypeOf(FormStore)).call(this, pristineValue, _extends({}, options, {
			key: '<FORM>'
		})));

		_initDefineProp(_this, 'submit', _descriptor, _this);

		_initDefineProp(_this, 'reset', _descriptor2, _this);

		_initDefineProp(_this, 'clear', _descriptor3, _this);

		var submit = options.submit,
		    clear = options.clear,
		    reset = options.reset,
		    change = options.change;

		_this.bus = _extends({}, _this.bus, {
			submit: submit,
			change: change,
			clear: clear,
			reset: reset
		});
		return _this;
	}

	_createClass(FormStore, [{
		key: 'createChildren',
		value: function createChildren(parentStore, key, value, options) {
			var isArray = options.isArray,
			    isObject = options.isObject,
			    isRadio = options.isRadio;

			// enforce array type if value is array

			if (!isArray && isArrayType(value)) {
				var _store = parentStore.getChildren(key);
				if (!_store) {
					_store = parentStore.attach(key, { isArray: true, parentStore: parentStore });
				}
				return _store.attach(createId(key), options);
			}

			if (isRadio) {
				var _store2 = parentStore.getChildren(key);
				if (!_store2) {
					_store2 = parentStore.attach(key, {
						isArray: true,
						isObject: true,
						isRadioGroup: true,
						parentStore: parentStore,
						inputFilter: function inputFilter(val) {
							return [val];
						},
						outputFilter: function outputFilter(val) {
							return val[0];
						},
						onChange: function onChange(_ref) {
							var key = _ref.key;
							return _store2.checkKey(key);
						}
					});
				}

				return _store2.attach(createId(key), _extends({}, options, {
					isRadio: false
				}));
			}

			var Store = function () {
				if (isArray) return ArrayStore;
				if (isObject) return ObjectStore;
				return PrimitiveStore;
			}();

			var checkable = options.checkable,
			    propValue = options.value;

			var finalPristineValue = checkable ? propValue : value;
			var store = new Store(finalPristineValue, _extends({}, options, {
				key: key,
				form: this,
				parentStore: parentStore
			}));
			parentStore.setChildren(key, store);
			return store;
		}
	}]);

	return FormStore;
}(ObjectStore), (_applyDecoratedDescriptor(_class.prototype, 'createChildren', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'createChildren'), _class.prototype), _descriptor = _applyDecoratedDescriptor(_class.prototype, 'submit', [action], {
	enumerable: true,
	initializer: function initializer() {
		var _this2 = this;

		return function () {
			var isValid = _this2.isValid;
			var submit = _this2.bus.submit;

			_this2.touch();

			/* istanbul ignore else */
			if (isFunction(submit)) {
				var value = _this2.getFormData();
				submit(value, { isValid: isValid });
				return isValid ? value : null;
			}
		};
	}
}), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, 'reset', [action], {
	enumerable: true,
	initializer: function initializer() {
		var _this3 = this;

		return function () {
			var pristineValue = _this3.pristineValue;

			_this3.pristineValue = pristineValue;
		};
	}
}), _descriptor3 = _applyDecoratedDescriptor(_class.prototype, 'clear', [action], {
	enumerable: true,
	initializer: function initializer() {
		var _this4 = this;

		return function () {
			_this4.pristineValue = {};
		};
	}
})), _class);
export { FormStore as default };

==> react-form-mobx-0.4.0.tgz: package/es/FormStore/FormStore.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class, _descriptor, _descriptor2, _descriptor3;

function _initDefineProp(target, property, descriptor, context) {
	if (!descriptor) return;
	Object.defineProperty(target, property, {
		enumerable: descriptor.enumerable,
		configurable: descriptor.configurable,
		writable: descriptor.writable,
		value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	});
}

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _initializerWarningHelper(descriptor, context) {
	throw new Error('Decorating class property failed. Please ensure that transform-class-properties is enabled.');
}

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

import { action } from 'mobx';
import { isFunction, createId } from '../utils';
import PrimitiveStore from './PrimitiveStore';
import ObjectStore from './ObjectStore';
import ArrayStore from './ArrayStore';

var FormStore = (_class = function (_ObjectStore) {
	_inherits(FormStore, _ObjectStore);

	function FormStore(pristineValue, options) {
		_classCallCheck(this, FormStore);

		var _this = _possibleConstructorReturn(this, (FormStore.__proto__ || Object.getPrototypeOf(FormStore)).call(this, pristineValue, _extends({}, options, {
			key: '<FORM>'
		})));

		_initDefineProp(_this, 'submit', _descriptor, _this);

		_initDefineProp(_this, 'reset', _descriptor2, _this);

		_initDefineProp(_this, 'clear', _descriptor3, _this);

		var submit = options.submit,
		    clear = options.clear,
		    reset = options.reset,
		    change = options.change;

		_this.bus = _extends({}, _this.bus, {
			submit: submit,
			change: change,
			clear: clear,
			reset: reset
		});
		return _this;
	}

	_createClass(FormStore, [{
		key: 'createChildren',
		value: function createChildren(parentStore, key, value, options) {
			var isArray = options.isArray,
			    isObject = options.isObject,
			    isRadio = options.isRadio;


			if (isRadio) {
				var _store = parentStore.getChildren(key);
				if (!_store) {
					_store = parentStore.attach(key, {
						isArray: true,
						isObject: true,
						isRadioGroup: true,
						parentStore: parentStore,
						inputFilter: function inputFilter(val) {
							return [val];
						},
						outputFilter: function outputFilter(val) {
							return val[0];
						},
						onChange: function onChange(_ref) {
							var key = _ref.key;
							return _store.checkKey(key);
						}
					});
				}

				return _store.attach(createId(key), _extends({}, options, {
					isRadio: false
				}));
			}

			var Store = function () {
				if (isArray) return ArrayStore;
				if (isObject) return ObjectStore;
				return PrimitiveStore;
			}();

			var checkable = options.checkable,
			    propValue = options.value;

			var finalPristineValue = checkable ? propValue : value;
			var store = new Store(finalPristineValue, _extends({}, options, {
				key: key,
				form: this,
				parentStore: parentStore
			}));
			parentStore.setChildren(key, store);
			return store;
		}
	}]);

	return FormStore;
}(ObjectStore), (_applyDecoratedDescriptor(_class.prototype, 'createChildren', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'createChildren'), _class.prototype), _descriptor = _applyDecoratedDescriptor(_class.prototype, 'submit', [action], {
	enumerable: true,
	initializer: function initializer() {
		var _this2 = this;

		return function () {
			var isValid = _this2.isValid;
			var submit = _this2.bus.submit;

			_this2.touch();

			/* istanbul ignore else */
			if (isFunction(submit)) {
				var value = _this2.getFormData();
				submit(value, { isValid: isValid });
				return isValid ? value : null;
			}
		};
	}
}), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, 'reset', [action], {
	enumerable: true,
	initializer: function initializer() {
		var _this3 = this;

		return function () {
			var pristineValue = _this3.pristineValue;

			_this3.pristineValue = pristineValue;
		};
	}
}), _descriptor3 = _applyDecoratedDescriptor(_class.prototype, 'clear', [action], {
	enumerable: true,
	initializer: function initializer() {
		var _this4 = this;

		return function () {
			_this4.pristineValue = {};
		};
	}
})), _class);
export { FormStore as default };
